Bump version
[libdcp.git] / src / dcp.h
index d6237e8af4ae14eff89d80306b4de8b621d0546d..635a972d65a07c3e961abaacd21741effb043a02 100644 (file)
--- a/src/dcp.h
+++ b/src/dcp.h
@@ -47,9 +47,13 @@ class SubtitleAsset;
 class Reel;
 class CPL;
 class XMLMetadata;
-class Encryption;
+class Signer;
 class KDM;
 
+namespace parse {
+       class AssetMap;
+}
+
 /** @class DCP
  *  @brief A class to create or read a DCP.
  */
@@ -63,22 +67,23 @@ public:
         *
         *  @param directory Directory containing the DCP's files.
         */
-       DCP (std::string directory);
+       DCP (boost::filesystem::path directory);
+
+       void read (bool require_mxfs = true);
 
/** Read an existing DCP's data.
         *
         *  The DCP's XML metadata will be examined, and you can then look at the contents
         *  of the DCP.
-        *
-        *  @param require_mxfs true to throw an exception if MXF files are missing; setting to false
-        *  can be useful for testing, but normally it should be set to true.
         */
-       void read (bool require_mxfs = true);
+       void read_assets ();
+
+       void read_cpls (bool require_mxfs = true);
 
        /** Write the required XML files to the directory that was
         *  passed into the constructor.
         */
-       void write_xml (bool interop, XMLMetadata const &, boost::shared_ptr<Encryption> crypt = boost::shared_ptr<Encryption> ()) const;
+       void write_xml (bool interop, XMLMetadata const &, boost::shared_ptr<const Signer> signer = boost::shared_ptr<const Signer> ()) const;
 
        /** Compare this DCP with another, according to various options.
         *  @param other DCP to compare this one to.
@@ -97,6 +102,16 @@ public:
                return _cpls;
        }
 
+       /** Add another DCP as a source of assets for this DCP.  This should be called before
+        *  ::read() on the DCP that needs the extra assets.  For example
+        *
+        *  DCP original_version ("my_dcp_OV");
+        *  DCP supplemental ("my_dcp_VF");
+        *  supplemental.add_assets_from (original_version);
+        *  supplemental.read ();
+        */
+       void add_assets_from (libdcp::DCP const &);
+
        bool encrypted () const;
 
        void add_kdm (KDM const &);
@@ -111,7 +126,7 @@ private:
        /** Write the PKL file.
         *  @param pkl_uuid UUID to use.
         */
-       std::string write_pkl (std::string pkl_uuid, bool, XMLMetadata const &, boost::shared_ptr<Encryption>) const;
+       std::string write_pkl (std::string pkl_uuid, bool, XMLMetadata const &, boost::shared_ptr<const Signer>) const;
        
        /** Write the VOLINDEX file */
        void write_volindex () const;
@@ -122,7 +137,7 @@ private:
         */
        void write_assetmap (std::string pkl_uuid, int pkl_length, bool, XMLMetadata const &) const;
 
-       /** @return Assets in all this CPLs in this DCP */
+       /** @return Assets in all the CPLs in this DCP */
        std::list<boost::shared_ptr<const Asset> > assets () const;
 
        struct Files {
@@ -131,10 +146,14 @@ private:
                std::string asset_map;
        };
 
+       Files _files;
+
        /** the directory that we are writing to */
-       std::string _directory;
+       boost::filesystem::path _directory;
        /** our CPLs */
        std::list<boost::shared_ptr<CPL> > _cpls;
+
+       std::list<PathAssetMap> _asset_maps;
 };
 
 }
@@ -63,22 +67,23 @@ public:
 
-       /** Read an existing DCP's data.
+       /** Read an existing DCP's assets.
         *
         *  The DCP's XML metadata will be examined, and you can then look at the contents